---
sidebar_position: 5
---

# Case study: training a classifier from lab data

:::note
This case study is still **under construction**.
:::

## Introduction

## Methodology

## Results

## Discussion

## Conclusion